'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var ReactDOM = _interopDefault(require('react-dom'));
var zcreate = _interopDefault(require('zustand'));

function create(hook) {
  var useZStore = zcreate(function () {
    return {};
  });
  var reactRoot = document.createElement('div');

  for (var _len = arguments.length, hookArgs = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    hookArgs[_key - 1] = arguments[_key];
  }

  ReactDOM.render(React__default.createElement(StoreComponent, {
    hook: hook,
    hookArgs: hookArgs,
    useZStore: useZStore
  }), reactRoot);

  function internalSelector(selector) {
    return function (_ref) {
      var value = _ref.value;
      if (value == null) return value;

      if (typeof selector === 'function') {
        return selector(value);
      }

      return value;
    };
  }

  function internalIsEqual(eqFn) {
    if (typeof eqFn === 'function') {
      return function (_ref2, _ref3) {
        var prevValue = _ref2.value;
        var nextValue = _ref3.value;
        return eqFn(prevValue, nextValue);
      };
    }

    return undefined;
  }

  function useStore(selector, isEqual) {
    return useZStore( // @ts-ignore
    internalSelector(selector), // @ts-ignore
    internalIsEqual(isEqual));
  }

  useStore.getState = function () {
    return useZStore.getState().value;
  };

  useStore.subscribe = function subscribe(listener, selector, isEqual) {
    return useZStore.subscribe( // @ts-ignore
    listener, internalSelector(selector), isEqual);
  };

  useStore.destroy = function () {
    return useZStore.destroy();
  };

  return useStore;
}

function StoreComponent(_ref4) {
  var useHook = _ref4.hook,
      hookArgs = _ref4.hookArgs,
      useZStore = _ref4.useZStore;
  var result = useHook.apply(void 0, hookArgs);
  React.useEffect(function () {
    useZStore.setState({
      value: result
    });
  }, [useZStore, result]);
  return null;
}

exports.default = create;
//# sourceMappingURL=zusteller.cjs.development.js.map
